@@ -8,11 +8,11 @@ PDL::Stats - a collection of statistics modules in Perl Data Language, with a qu
 
 =head1 VERSION
 
-Version 0.6.5
+Version 0.6.5_1
 
 =cut
 
-$VERSION = '0.6.5';
+$VERSION = '0.6.5_1';
 
 $PDL::onlinedoc->scan(__FILE__) if $PDL::onlinedoc;
 
@@ -128,7 +128,7 @@ Here the function corr takes two inputs, two 1D pdl with the same numbers of ele
     
       Signature: (a(n); b(m); float+ [o]t(); [o]d())
 
-Here the function t_test can take two 1D pdls of unequal size (n==m is certainly fine), and give back two scalars, t-value and degrees of freedom. Yes we accomodate t-tests with unequal sample sizes.
+Here the function t_test can take two 1D pdls of unequal size (n==m is certainly fine), and give back two scalars, t-value and degrees of freedom. Yes we accommodate t-tests with unequal sample sizes.
 
     assign
     
